@@ -3,7 +3,7 @@
 import "base" Control.Applicative (pure)
 import "base" Data.Function (const, ($))
 import "base" System.IO (IO)
-import qualified "this" Test.IgnoreDefaultImpls as IgnoreDefaultImpls
+import "this" Test.IgnoreDefaultImpls qualified as IgnoreDefaultImpls
 
 main :: IO ()
 main = pure $ const () IgnoreDefaultImpls.Empty
